{ config, pkgs, ... }:
{
  # GTK Theme
  gtk = {
    enable = true;

    iconTheme = {
      name = "Papirus-Dark";
      package = pkgs.papirus-icon-theme;
    };

    theme = {
      name = "Yaru-purple-dark";
      package = pkgs.yaru-theme;
    };

    cursorTheme = {
      name = "Numix-Cursor";
      package = pkgs.numix-cursor-theme;
    };

    gtk3.extraConfig = {
      Settings = ''
        gtk-application-prefer-dark-theme=1
      '';
    };

    gtk4.extraConfig = {
      Settings = ''
        gtk-application-prefer-dark-theme=1
      '';
    };
  };

  dconf = {
    enable = true;
    settings = {
      # Set nemo as the default file manager and disable desktop icons since this is handled by nemo
      "org/gnome/desktop/background" = {
        show-desktop-icons = false;
      };
      "org/gnome/desktop/applications/file-manager" = {
        exec = "nemo";
      };

      "org/gnome/desktop/interface" = {
        color-scheme = "prefer-dark";
      };

      # Pinned apps
      # add more by listing them with `gsettings list-recursively | grep favorite-apps | sed "s/,//g; s/'/\"/g"` then copy pasting the output here
      "org/gnome/shell" = {
        favorite-apps = [
          "brave-browser.desktop"
          "code.desktop"
          "org.telegram.desktop.desktop"
          "spotify.desktop"
          "com.plexamp.Plexamp.desktop"
          "vesktop.desktop"
          "org.gnome.Geary.desktop"
          "nemo.desktop"
          "org.gnome.Console.desktop"
        ];
      };

      # GNOME Terminal settings
      "org/gnome/Console" = {
        use-system-font = false;
        custom-font = "Hack Nerd Font 13";
        theme = "night";
      };

      # Set wallpaper
      "org/gnome/desktop/background" = {
        picture-uri-dark = "file:///${config.home.homeDirectory}/dotfiles/secrets/wp/9.png";
        picture-uri = "file:///${config.home.homeDirectory}/dotfiles/secrets/wp/9.png";
        picture-options = "zoom";
        primary-color = "#000000";
      };
    };
  };

}
