{
  config,
  lib,
  pkgs,
  modulesPath,
  ...
}:
{
  imports = [ /etc/nixos/hardware-configuration.nix ];
  networking.hostName = "mennos-gamingpc";

  fileSystems."/" = {
    device = "/dev/disk/by-uuid/ac5a70cf-4b12-4d02-b5b4-a6eddf4c40b5";
    fsType = "ext4";
    options = [ "noatime" ];
  };

  networking.interfaces.enp8s0.wakeOnLan = {
    enable = true;
  };

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  # Enable Vulkan support for AMD graphics cards
  hardware.graphics.extraPackages32 = with pkgs.pkgsi686Linux; [ amdvlk ];

  # Swap file (Desktop PC has 48GB of RAM so 8GB swap should be enough)
  swapDevices = [
    {
      device = "/swapfile";
      size = 8192;
    }
  ];

  # Enable graphics
  hardware.graphics = {
    enable = true;

    # Enable the latest AMDGPU drivers
    extraPackages = with pkgs; [
      amdvlk
      rocmPackages.clr
    ];
  };

  # Add ROCm packages and nvtop
  environment.systemPackages = with pkgs; [
    rocmPackages.rocm-smi
    rocmPackages.clr
    rocmPackages.rocm-core
    rocmPackages.hipcc
    rocmPackages.rocm-device-libs
    nvtopPackages.amd
  ];
}
